@@ -10,6 +10,7 @@ from Products.Five.browser import BrowserView
 from Globals import InitializeClass
 
 from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile
+from haufe.monitoring.network import isRequestAllowed
 
 
 class ErrorLogView(BrowserView):
@@ -21,6 +22,8 @@ class ErrorLogView(BrowserView):
 
     def collect_error_logs(self):
 
+        isRequestAllowed(self.request)
+
         result = list()
         for hostSpec in self.request.get('hosts', []):
             host, port = hostSpec.split(':') # host:port
